==> ugene_34.0+dfsg.orig.tar.xz: ugene-34.0/src/plugins/dna_graphpack/src/EntropyAlgorithm.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GRAPHPACK_ENTROPY_H_
#define _U2_GRAPHPACK_ENTROPY_H_

#include "DNAGraphPackPlugin.h"

#include <U2View/GSequenceGraphView.h>

#include <QAction>
#include <QList>
#include <QBitArray>

namespace U2 {

class AnnotatedDNAView;

class EntropyGraphFactory : public GSequenceGraphFactory {
    Q_OBJECT
public:
    EntropyGraphFactory(QObject* p);
    QList<QSharedPointer<GSequenceGraphData> > createGraphs(GSequenceGraphView* v);
    bool isEnabled(const U2SequenceObject* o) const;
};

class EntropyGraphAlgorithm : public GSequenceGraphAlgorithm {
public:
    void calculate(QVector<float>& res, U2SequenceObject* o, const U2Region& r, const GSequenceGraphWindowData* d, U2OpStatus &os);
};

} // namespace
#endif

==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/dna_graphpack/src/EntropyAlgorithm.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GRAPHPACK_ENTROPY_H_
#define _U2_GRAPHPACK_ENTROPY_H_

#include <QAction>
#include <QBitArray>
#include <QList>

#include <U2View/GSequenceGraphView.h>

#include "DNAGraphPackPlugin.h"

namespace U2 {

class AnnotatedDNAView;

class EntropyGraphFactory : public GSequenceGraphFactory {
    Q_OBJECT
public:
    EntropyGraphFactory(QObject *p);
    QList<QSharedPointer<GSequenceGraphData>> createGraphs(GSequenceGraphView *v);
    bool isEnabled(const U2SequenceObject *o) const;
};

class EntropyGraphAlgorithm : public GSequenceGraphAlgorithm {
public:
    void calculate(QVector<float> &result, U2SequenceObject *sequenceObject, qint64 window, qint64 step, U2OpStatus &os) override;
};

}  // namespace U2
#endif
